Customisation
=============
Various customisation examples:

- Address provider implementation.
- Band provider implementation.
- Replace built-in fake data corpus/vocabulary with a custom one.
- Override default data.

Testing
-------
.. code-block:: sh

    pytest

or

.. code-block:: sh

    python manage.py test
